@@ -177,7 +177,7 @@ typedef enum
  */
 #define EFL_NET_CONTROL_ACCESS_POINT_CLASS efl_net_control_access_point_class_get()
 
-EWAPI const Efl_Class *efl_net_control_access_point_class_get(void);
+ECORE_CON_API ECORE_CON_API_WEAK const Efl_Class *efl_net_control_access_point_class_get(void) EINA_CONST;
 
 /**
  * @brief Connects to this access point.
@@ -203,7 +203,7 @@ EWAPI const Efl_Class *efl_net_control_access_point_class_get(void);
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Future *efl_net_control_access_point_connect(Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
+ECORE_CON_API ECORE_CON_API_WEAK Eina_Future *efl_net_control_access_point_connect(Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Disconnects from this access point.
@@ -218,7 +218,7 @@ EOAPI Eina_Future *efl_net_control_access_point_connect(Eo *obj) EFL_TRANSFER_OW
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_disconnect(Eo *obj);
+ECORE_CON_API ECORE_CON_API_WEAK void efl_net_control_access_point_disconnect(Eo *obj);
 
 /**
  * @brief Disconnects and forgets about this access point.
@@ -231,7 +231,7 @@ EOAPI void efl_net_control_access_point_disconnect(Eo *obj);
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_forget(Eo *obj);
+ECORE_CON_API ECORE_CON_API_WEAK void efl_net_control_access_point_forget(Eo *obj);
 
 /**
  * @brief The current state of the access point.
@@ -244,7 +244,7 @@ EOAPI void efl_net_control_access_point_forget(Eo *obj);
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Efl_Net_Control_Access_Point_State efl_net_control_access_point_state_get(const Eo *obj);
+ECORE_CON_API ECORE_CON_API_WEAK Efl_Net_Control_Access_Point_State efl_net_control_access_point_state_get(const Eo *obj);
 
 /**
  * @brief If the access point is in error state, this states the error.
@@ -255,7 +255,7 @@ EOAPI Efl_Net_Control_Access_Point_State efl_net_control_access_point_state_get(
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Efl_Net_Control_Access_Point_Error efl_net_control_access_point_error_get(const Eo *obj);
+ECORE_CON_API ECORE_CON_API_WEAK Efl_Net_Control_Access_Point_Error efl_net_control_access_point_error_get(const Eo *obj);
 
 /**
  * @brief The user-friendly access point name.
@@ -268,7 +268,7 @@ EOAPI Efl_Net_Control_Access_Point_Error efl_net_control_access_point_error_get(
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI const char *efl_net_control_access_point_ssid_get(const Eo *obj);
+ECORE_CON_API ECORE_CON_API_WEAK const char *efl_net_control_access_point_ssid_get(const Eo *obj);
 
 /**
  * @brief The access point priority in the current access point listing.
@@ -290,7 +290,7 @@ EOAPI const char *efl_net_control_access_point_ssid_get(const Eo *obj);
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_priority_set(Eo *obj, unsigned int priority);
+ECORE_CON_API ECORE_CON_API_WEAK void efl_net_control_access_point_priority_set(Eo *obj, unsigned int priority);
 
 /**
  * @brief The access point priority in the current access point listing.
@@ -313,7 +313,7 @@ EOAPI void efl_net_control_access_point_priority_set(Eo *obj, unsigned int prior
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI unsigned int efl_net_control_access_point_priority_get(const Eo *obj);
+ECORE_CON_API ECORE_CON_API_WEAK unsigned int efl_net_control_access_point_priority_get(const Eo *obj);
 
 /**
  * @brief The technology that generated this access point
@@ -324,7 +324,7 @@ EOAPI unsigned int efl_net_control_access_point_priority_get(const Eo *obj);
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Efl_Net_Control_Technology *efl_net_control_access_point_technology_get(const Eo *obj);
+ECORE_CON_API ECORE_CON_API_WEAK Efl_Net_Control_Technology *efl_net_control_access_point_technology_get(const Eo *obj);
 
 /**
  * @brief Signal strength percentage in 0-100
@@ -335,7 +335,7 @@ EOAPI Efl_Net_Control_Technology *efl_net_control_access_point_technology_get(co
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI uint8_t efl_net_control_access_point_strength_get(const Eo *obj);
+ECORE_CON_API ECORE_CON_API_WEAK uint8_t efl_net_control_access_point_strength_get(const Eo *obj);
 
 /**
  * @brief If it's a cellular access point and it's on roaming.
@@ -347,7 +347,7 @@ EOAPI uint8_t efl_net_control_access_point_strength_get(const Eo *obj);
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Bool efl_net_control_access_point_roaming_get(const Eo *obj);
+ECORE_CON_API ECORE_CON_API_WEAK Eina_Bool efl_net_control_access_point_roaming_get(const Eo *obj);
 
 /**
  * @brief Whenever to auto-connect to this access point if no other is
@@ -365,7 +365,7 @@ EOAPI Eina_Bool efl_net_control_access_point_roaming_get(const Eo *obj);
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_auto_connect_set(Eo *obj, Eina_Bool auto_connect);
+ECORE_CON_API ECORE_CON_API_WEAK void efl_net_control_access_point_auto_connect_set(Eo *obj, Eina_Bool auto_connect);
 
 /**
  * @brief Whenever to auto-connect to this access point if no other is
@@ -384,7 +384,7 @@ EOAPI void efl_net_control_access_point_auto_connect_set(Eo *obj, Eina_Bool auto
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Bool efl_net_control_access_point_auto_connect_get(const Eo *obj);
+ECORE_CON_API ECORE_CON_API_WEAK Eina_Bool efl_net_control_access_point_auto_connect_get(const Eo *obj);
 
 /**
  * @brief Successfully connected access points are remembered.
@@ -398,7 +398,7 @@ EOAPI Eina_Bool efl_net_control_access_point_auto_connect_get(const Eo *obj);
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Bool efl_net_control_access_point_remembered_get(const Eo *obj);
+ECORE_CON_API ECORE_CON_API_WEAK Eina_Bool efl_net_control_access_point_remembered_get(const Eo *obj);
 
 /**
  * @brief Immutable access points are those defined in configuration files and
@@ -410,7 +410,7 @@ EOAPI Eina_Bool efl_net_control_access_point_remembered_get(const Eo *obj);
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Bool efl_net_control_access_point_immutable_get(const Eo *obj);
+ECORE_CON_API ECORE_CON_API_WEAK Eina_Bool efl_net_control_access_point_immutable_get(const Eo *obj);
 
 /**
  * @brief Security options such as WEP, WPS, PSK or none (open).
@@ -421,7 +421,7 @@ EOAPI Eina_Bool efl_net_control_access_point_immutable_get(const Eo *obj);
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Efl_Net_Control_Access_Point_Security efl_net_control_access_point_security_get(const Eo *obj);
+ECORE_CON_API ECORE_CON_API_WEAK Efl_Net_Control_Access_Point_Security efl_net_control_access_point_security_get(const Eo *obj);
 
 /**
  * @brief DNS (Domain Name Servers) in use for this access point.
@@ -436,7 +436,7 @@ EOAPI Efl_Net_Control_Access_Point_Security efl_net_control_access_point_securit
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Iterator *efl_net_control_access_point_name_servers_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
+ECORE_CON_API ECORE_CON_API_WEAK Eina_Iterator *efl_net_control_access_point_name_servers_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief NTP (Time Server) in use for this access point.
@@ -451,7 +451,7 @@ EOAPI Eina_Iterator *efl_net_control_access_point_name_servers_get(const Eo *obj
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Iterator *efl_net_control_access_point_time_servers_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
+ECORE_CON_API ECORE_CON_API_WEAK Eina_Iterator *efl_net_control_access_point_time_servers_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Searches domains in use for this access point.
@@ -466,7 +466,7 @@ EOAPI Eina_Iterator *efl_net_control_access_point_time_servers_get(const Eo *obj
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Iterator *efl_net_control_access_point_domains_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
+ECORE_CON_API ECORE_CON_API_WEAK Eina_Iterator *efl_net_control_access_point_domains_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief IPv4 in use for this access point.
@@ -483,7 +483,7 @@ EOAPI Eina_Iterator *efl_net_control_access_point_domains_get(const Eo *obj) EFL
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_ipv4_get(const Eo *obj, Efl_Net_Control_Access_Point_Ipv4_Method *method, const char **address, const char **netmask, const char **gateway);
+ECORE_CON_API ECORE_CON_API_WEAK void efl_net_control_access_point_ipv4_get(const Eo *obj, Efl_Net_Control_Access_Point_Ipv4_Method *method, const char **address, const char **netmask, const char **gateway);
 
 /**
  * @brief IPv6 in use for this access point.
@@ -501,7 +501,7 @@ EOAPI void efl_net_control_access_point_ipv4_get(const Eo *obj, Efl_Net_Control_
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_ipv6_get(const Eo *obj, Efl_Net_Control_Access_Point_Ipv6_Method *method, const char **address, uint8_t *prefix_length, const char **netmask, const char **gateway);
+ECORE_CON_API ECORE_CON_API_WEAK void efl_net_control_access_point_ipv6_get(const Eo *obj, Efl_Net_Control_Access_Point_Ipv6_Method *method, const char **address, uint8_t *prefix_length, const char **netmask, const char **gateway);
 
 /**
  * @brief Proxy in use for this access point.
@@ -524,7 +524,7 @@ EOAPI void efl_net_control_access_point_ipv6_get(const Eo *obj, Efl_Net_Control_
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_proxy_get(const Eo *obj, Efl_Net_Control_Access_Point_Proxy_Method *method, const char **url, Eina_Iterator **servers EFL_TRANSFER_OWNERSHIP, Eina_Iterator **excludes EFL_TRANSFER_OWNERSHIP);
+ECORE_CON_API ECORE_CON_API_WEAK void efl_net_control_access_point_proxy_get(const Eo *obj, Efl_Net_Control_Access_Point_Proxy_Method *method, const char **url, Eina_Iterator **servers EFL_TRANSFER_OWNERSHIP, Eina_Iterator **excludes EFL_TRANSFER_OWNERSHIP);
 
 /**
  * @brief DNS (Domain Name Servers) configured by user for this access point.
@@ -539,7 +539,7 @@ EOAPI void efl_net_control_access_point_proxy_get(const Eo *obj, Efl_Net_Control
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_configuration_name_servers_set(Eo *obj, Eina_Iterator *name_servers EFL_TRANSFER_OWNERSHIP);
+ECORE_CON_API ECORE_CON_API_WEAK void efl_net_control_access_point_configuration_name_servers_set(Eo *obj, Eina_Iterator *name_servers EFL_TRANSFER_OWNERSHIP);
 
 /**
  * @brief DNS (Domain Name Servers) configured by user for this access point.
@@ -555,7 +555,7 @@ EOAPI void efl_net_control_access_point_configuration_name_servers_set(Eo *obj,
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Iterator *efl_net_control_access_point_configuration_name_servers_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
+ECORE_CON_API ECORE_CON_API_WEAK Eina_Iterator *efl_net_control_access_point_configuration_name_servers_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief NTP (Time Server) configured by user for this access point.
@@ -570,7 +570,7 @@ EOAPI Eina_Iterator *efl_net_control_access_point_configuration_name_servers_get
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_configuration_time_servers_set(Eo *obj, Eina_Iterator *time_servers EFL_TRANSFER_OWNERSHIP);
+ECORE_CON_API ECORE_CON_API_WEAK void efl_net_control_access_point_configuration_time_servers_set(Eo *obj, Eina_Iterator *time_servers EFL_TRANSFER_OWNERSHIP);
 
 /**
  * @brief NTP (Time Server) configured by user for this access point.
@@ -586,7 +586,7 @@ EOAPI void efl_net_control_access_point_configuration_time_servers_set(Eo *obj,
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Iterator *efl_net_control_access_point_configuration_time_servers_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
+ECORE_CON_API ECORE_CON_API_WEAK Eina_Iterator *efl_net_control_access_point_configuration_time_servers_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Searches domains configured by user for this access point.
@@ -601,7 +601,7 @@ EOAPI Eina_Iterator *efl_net_control_access_point_configuration_time_servers_get
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_configuration_domains_set(Eo *obj, Eina_Iterator *domains EFL_TRANSFER_OWNERSHIP);
+ECORE_CON_API ECORE_CON_API_WEAK void efl_net_control_access_point_configuration_domains_set(Eo *obj, Eina_Iterator *domains EFL_TRANSFER_OWNERSHIP);
 
 /**
  * @brief Searches domains configured by user for this access point.
@@ -617,7 +617,7 @@ EOAPI void efl_net_control_access_point_configuration_domains_set(Eo *obj, Eina_
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI Eina_Iterator *efl_net_control_access_point_configuration_domains_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
+ECORE_CON_API ECORE_CON_API_WEAK Eina_Iterator *efl_net_control_access_point_configuration_domains_get(const Eo *obj) EFL_TRANSFER_OWNERSHIP EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief IPv4 configured by user for this access point.
@@ -635,7 +635,7 @@ EOAPI Eina_Iterator *efl_net_control_access_point_configuration_domains_get(cons
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_configuration_ipv4_set(Eo *obj, Efl_Net_Control_Access_Point_Ipv4_Method method, const char *address, const char *netmask, const char *gateway);
+ECORE_CON_API ECORE_CON_API_WEAK void efl_net_control_access_point_configuration_ipv4_set(Eo *obj, Efl_Net_Control_Access_Point_Ipv4_Method method, const char *address, const char *netmask, const char *gateway);
 
 /**
  * @brief IPv4 configured by user for this access point.
@@ -653,7 +653,7 @@ EOAPI void efl_net_control_access_point_configuration_ipv4_set(Eo *obj, Efl_Net_
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_configuration_ipv4_get(const Eo *obj, Efl_Net_Control_Access_Point_Ipv4_Method *method, const char **address, const char **netmask, const char **gateway);
+ECORE_CON_API ECORE_CON_API_WEAK void efl_net_control_access_point_configuration_ipv4_get(const Eo *obj, Efl_Net_Control_Access_Point_Ipv4_Method *method, const char **address, const char **netmask, const char **gateway);
 
 /**
  * @brief IPv6 configured by user for this access point.
@@ -672,7 +672,7 @@ EOAPI void efl_net_control_access_point_configuration_ipv4_get(const Eo *obj, Ef
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_configuration_ipv6_set(Eo *obj, Efl_Net_Control_Access_Point_Ipv6_Method method, const char *address, uint8_t prefix_length, const char *netmask, const char *gateway);
+ECORE_CON_API ECORE_CON_API_WEAK void efl_net_control_access_point_configuration_ipv6_set(Eo *obj, Efl_Net_Control_Access_Point_Ipv6_Method method, const char *address, uint8_t prefix_length, const char *netmask, const char *gateway);
 
 /**
  * @brief IPv6 configured by user for this access point.
@@ -691,7 +691,7 @@ EOAPI void efl_net_control_access_point_configuration_ipv6_set(Eo *obj, Efl_Net_
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_configuration_ipv6_get(const Eo *obj, Efl_Net_Control_Access_Point_Ipv6_Method *method, const char **address, uint8_t *prefix_length, const char **netmask, const char **gateway);
+ECORE_CON_API ECORE_CON_API_WEAK void efl_net_control_access_point_configuration_ipv6_get(const Eo *obj, Efl_Net_Control_Access_Point_Ipv6_Method *method, const char **address, uint8_t *prefix_length, const char **netmask, const char **gateway);
 
 /**
  * @brief Proxy configured by user for this access point.
@@ -715,7 +715,7 @@ EOAPI void efl_net_control_access_point_configuration_ipv6_get(const Eo *obj, Ef
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_configuration_proxy_set(Eo *obj, Efl_Net_Control_Access_Point_Proxy_Method method, const char *url, Eina_Iterator *servers EFL_TRANSFER_OWNERSHIP, Eina_Iterator *excludes EFL_TRANSFER_OWNERSHIP);
+ECORE_CON_API ECORE_CON_API_WEAK void efl_net_control_access_point_configuration_proxy_set(Eo *obj, Efl_Net_Control_Access_Point_Proxy_Method method, const char *url, Eina_Iterator *servers EFL_TRANSFER_OWNERSHIP, Eina_Iterator *excludes EFL_TRANSFER_OWNERSHIP);
 
 /**
  * @brief Proxy configured by user for this access point.
@@ -739,9 +739,9 @@ EOAPI void efl_net_control_access_point_configuration_proxy_set(Eo *obj, Efl_Net
  *
  * @ingroup Efl_Net_Control_Access_Point
  */
-EOAPI void efl_net_control_access_point_configuration_proxy_get(const Eo *obj, Efl_Net_Control_Access_Point_Proxy_Method *method, const char **url, Eina_Iterator **servers EFL_TRANSFER_OWNERSHIP, Eina_Iterator **excludes EFL_TRANSFER_OWNERSHIP);
+ECORE_CON_API ECORE_CON_API_WEAK void efl_net_control_access_point_configuration_proxy_get(const Eo *obj, Efl_Net_Control_Access_Point_Proxy_Method *method, const char **url, Eina_Iterator **servers EFL_TRANSFER_OWNERSHIP, Eina_Iterator **excludes EFL_TRANSFER_OWNERSHIP);
 
-EWAPI extern const Efl_Event_Description _EFL_NET_CONTROL_ACCESS_POINT_EVENT_CHANGED;
+ECORE_CON_API ECORE_CON_API_WEAK extern const Efl_Event_Description _EFL_NET_CONTROL_ACCESS_POINT_EVENT_CHANGED;
 
 /** Called when some properties were changed.
  *
