@@ -29,6 +29,6 @@ typedef Eo Efl_Ui_Box_Stack;
  */
 #define EFL_UI_BOX_STACK_CLASS efl_ui_box_stack_class_get()
 
-EWAPI const Efl_Class *efl_ui_box_stack_class_get(void);
+EAPI EAPI_WEAK const Efl_Class *efl_ui_box_stack_class_get(void) EINA_CONST;
 
 #endif
